netapp_ontap.models.volume_efficiency_space_savings API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_efficiency_space_savings`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeEfficiencySpaceSavingsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeEfficiencySpaceSavings object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `compression: Size GET`

    Total disk space that is saved by compressing blocks on the referenced file system, in bytes.

  `compression_percent: Size GET`

    Percentage of total disk space that is saved by compressing blocks on the referenced file system.

  `dedupe: Size GET`

    Total disk space that is saved by deduplication and file cloning, in bytes.

  `dedupe_percent: Size GET`

    Percentage of total disk space that is saved by deduplication and file cloning.

  `dedupe_sharing: Size GET`

    Total disk space that is shared due to deduplication and file cloning.

  `total: Size GET`

    Total disk space saved in the volume due to deduplication, compression and file cloning, in bytes.

  `total_percent: Size GET`

    Percentage of total disk space saved in the volume due to deduplication, compression and file cloning.